Indicators

Struct Indicators 

pub struct Indicators { /* private fields */ }
Registry for actor and strategy indicator callbacks.

Implementations

Source

impl Indicators

pub fn registered_indicators(&self) -> Vec<SharedActorIndicator>

Returns the registered indicators.

pub fn initialized(&self) -> Result<bool>

Returns whether all registered indicators are initialized.

Errors

Returns an error if a registered indicator cannot report readiness.

pub fn register_indicator_for_quote_ticks( &mut self, instrument_id: InstrumentId, indicator: SharedActorIndicator, )

Registers an indicator to receive quote ticks for an instrument.

pub fn register_indicator_for_trade_ticks( &mut self, instrument_id: InstrumentId, indicator: SharedActorIndicator, )

Registers an indicator to receive trade ticks for an instrument.

pub fn register_indicator_for_bars( &mut self, bar_type: BarType, indicator: SharedActorIndicator, )

Registers an indicator to receive bars for a bar type.

pub fn handle_quote(&self, quote: &QuoteTick) -> Result<()>

Handles a quote tick with registered indicators.

Errors

Returns an error if a registered indicator cannot handle the quote tick.

pub fn handle_quotes(&self, quotes: &[QuoteTick]) -> Result<()>

Handles quote ticks with registered indicators.

Errors

Returns an error if a registered indicator cannot handle a quote tick.

pub fn handle_trade(&self, trade: &TradeTick) -> Result<()>

Handles a trade tick with registered indicators.

Errors

Returns an error if a registered indicator cannot handle the trade tick.

pub fn handle_trades(&self, trades: &[TradeTick]) -> Result<()>

Handles trade ticks with registered indicators.

Errors

Returns an error if a registered indicator cannot handle a trade tick.

pub fn handle_bar(&self, bar: &Bar) -> Result<()>

Handles a bar with registered indicators.

Errors

Returns an error if a registered indicator cannot handle the bar.

pub fn handle_bars(&self, bars: &[Bar]) -> Result<()>

Handles bars with registered indicators.

Errors

Returns an error if a registered indicator cannot handle a bar.